#!/bin/bash
UL="\033[4m"
EUL="\033[0m"

USAGE="
Usage:
	$(basename $0) user [${UL}username${EUL}...]
	$(basename $0) pass ${UL}username${EUL}...
	$(basename $0) host [${UL}hostname${EUL}...]
"	

HELP="
Configures security options for Exchange FLR.

user	Sets user(s) that may access the Exchange FLR share. No ${UL}username${EUL}
	will print the current setting. A ${UL}username${EUL} of 'guest' will
	allow unauthenticated access to the share. This will create any
	${UL}username${EUL}	that is unknown to the system.

pass	Sets the samba password for each ${UL}username${EUL}. This will create
	any ${UL}username${EUL} that is unknown to the system.

host	Sets host(s) that may access the Exchange FLR share. No ${UL}hostname${EUL}
	will print the current setting. ${UL}hostname${EUL} of 'guest' will allow
	unrestricted access to the share.
"

exchange_user_security () {
	sed -i 's/^[ \t]*security = share[ \t]*$/\tsecurity = user/' /etc/samba/smb.conf
}

exchange_user_password () {
	if [ $# != 1 ]
	then
		echo "Invalid number of args, expected 1: ($#) $*"
		return
	fi

	echo "Setting password ${user}"
	smbpasswd -a $1
}

exchange_user_create () {
	for user in $*
	do
		if [ "${user}" == "guest" ]
		then
			continue
		fi

		if ! id ${user} > /dev/null 2>&1
		then
			echo "Creating user ${user}"
			useradd -M -d / -s /sbin/nologin ${user}
			exchange_user_password ${user}
		fi
	done
}

exchange_user_get () {
	bputil -g "ExchangeFLR" "ValidUsers" "guest" /usr/bp/bpinit/master.ini
}

exchange_user_set () {
	bputil -p "ExchangeFLR" "ValidUsers" "$*" /usr/bp/bpinit/master.ini
}

exchange_host_get () {
	bputil -g "ExchangeFLR" "HostsAllow" "guest" /usr/bp/bpinit/master.ini
}

exchange_host_set () {
	bputil -p "ExchangeFLR" "HostsAllow" "$*" /usr/bp/bpinit/master.ini
}

exchange_user () {
	if [ $# -eq 0 ]
	then
		exchange_user_get
	else
		exchange_user_security
		exchange_user_create $*
		exchange_user_set $*
	fi
}

exchange_pass () {
	for user in $*
	do
		if ! id ${user} > /dev/null 2>&1
		then
			exchange_user_create ${user}
		else
			exchange_user_password ${user}
		fi
	done
}

exchange_host () {
	if [ $# -eq 0 ]
	then
		exchange_host_get
	else
		exchange_host_set $*
	fi
}

ACTION=$1
shift 1

case ${ACTION} in
	user)
		exchange_user $*
		;;
	pass)
		exchange_pass $*
		;;
	host)
		exchange_host $*
		;;
	help)
		echo -e "${USAGE}\n${HELP}"
		exit
		;;
	*)
		echo -e "${USAGE}\n${HELP}"
		exit 1
		;;
esac



